@@ -4,7 +4,7 @@ package WebService::Rollbar::Notifier;
 use strict;
 use warnings;
 
-our $VERSION = '1.002003'; # TRIAL VERSION
+our $VERSION = '1.002007'; # TRIAL VERSION
 
 use Carp;
 use Scalar::Util qw/blessed/;
@@ -21,7 +21,7 @@ has callback => sub {
 };
 
 has environment => 'production';
-has [ qw/access_token  code_version framework language/ ];
+has [ qw/access_token  code_version framework language server/ ];
 
 sub critical { my $self = shift; $self->notify( 'critical', @_ ); }
 sub error    { my $self = shift; $self->notify( 'error',    @_ ); }
@@ -33,7 +33,7 @@ sub _parse_message_param {
     my $message = shift;
 
     if (ref($message) eq 'ARRAY') {
-        return ($message->[0], $message->[1]);
+        return ($message->[0], $message->[1]||{});
     } else {
         return ($message, {} );
     }
@@ -84,7 +84,6 @@ sub _parse_exception_params {
             class       => $class,
             (defined $message     ? (message => $message) : ()),
             (defined $description ? (description => $description) : ()),
-            hrump => 1,
         },
         $frames,
         $request_params,
@@ -141,7 +140,7 @@ sub _post {
 
     my @instance_optionals = (
         map +( defined $self->$_ ? ( $_ => $self->$_ ) : () ),
-            qw/code_version framework language/
+            qw/code_version framework language server/
     );
     my @request_optionals = (
         map +( exists $request_optionals->{$_} ? ( $_ => $request_optionals->{$_} ) : () ),
@@ -245,6 +244,7 @@ fully. Patches are more than welcome.
         environment     => 'production',
         code_version    => undef,
         framework       => undef,
+        server          => undef,
         callback        => sub {},
     );
 
@@ -301,6 +301,26 @@ git SHA (e.g. C<3da541559918a808c2402bba5012f6c60b27661c>).
 B<Optional>. B<By default> is not specified.
 The name of the framework your code uses
 
+=head3 C<server>
+
+=for html  <img alt="" src="http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/in-hashref.png">
+
+    my $roll = WebService::Rollbar::Notifier->new(
+        ...
+        server    => {
+            # Rollbar claims to understand following keys:
+            host    => "server_name",
+            root    => "/path/to/app/root/dir",
+            branch  => "branch_name",
+            code_version => "b6437f45b7bbbb15f5eddc2eace4c71a8625da8c",
+        }
+    );
+
+B<Optional>. B<By default> is not specified.
+Takes a hashref, which is used as "server" part of every Rollbar request made
+by this notifier instance. See L<https://rollbar.com/docs/api/items_post/> for
+detailed description of supported fields.
+
 =head3 C<callback>
 
 =for html  <img alt="" src="http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/in-subref.png">
@@ -470,7 +490,7 @@ that you want to send with your message. Full list of fields supported by
 Rollbar is available at L<https://rollbar.com/docs/api/items_post/>.
 
 Notable useful field is C<level> which can be used to set severity of your
-message. Default level is "info". See ->notify() for list of supported levels.
+message. Default level is "error". See ->notify() for list of supported levels.
 Other example fields supported by Rollbar include: context, request, person, server.
 
     $roll->report_message("Message to send", { context => "controller#action" });
@@ -499,7 +519,7 @@ L<https://rollbar.com/docs/api/items_post/>)
 
 =head3 $additional_parameters
 
-B<Optional>. Seel L</$additional_parameters> for details. Note that for
+B<Optional>. See L</$additional_parameters> for details. Note that for
 exceptions default level is "error".
 
 =for html  </div></div>
